ClientPermission

Enum ClientPermission 

#[non_exhaustive]
pub enum ClientPermission {
Show 18 variants None, EnableDisableNetwork, EnableDisableWifi, EnableDisableWwan, EnableDisableWimax, SleepWake, NetworkControl, WifiShareProtected, WifiShareOpen, SettingsModifySystem, SettingsModifyOwn, SettingsModifyHostname, SettingsModifyGlobalDns, Reload, CheckpointRollback, EnableDisableStatistics, EnableDisableConnectivityCheck, WifiScan,
}
#NMClientPermission values indicate various permissions that NetworkManager clients can obtain to perform certain tasks on behalf of the current user.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

unknown or no permission



EnableDisableNetwork

controls whether networking can be globally enabled or disabled



EnableDisableWifi

controls whether Wi-Fi can be globally enabled or disabled



EnableDisableWwan

controls whether WWAN (3G) can be globally enabled or disabled



EnableDisableWimax

controls whether WiMAX can be globally enabled or disabled



SleepWake

controls whether the client can ask NetworkManager to sleep and wake



NetworkControl

controls whether networking connections can be started, stopped, and changed



WifiShareProtected

controls whether a password protected Wi-Fi hotspot can be created



WifiShareOpen

controls whether an open Wi-Fi hotspot can be created



SettingsModifySystem

controls whether connections that are available to all users can be modified



SettingsModifyOwn

controls whether connections owned by the current user can be modified



SettingsModifyHostname

controls whether the persistent hostname can be changed



SettingsModifyGlobalDns

modify persistent global DNS configuration



Reload

controls access to Reload.



CheckpointRollback

permission to create checkpoints.



EnableDisableStatistics

controls whether device statistics can be globally enabled or disabled



EnableDisableConnectivityCheck

controls whether connectivity check can be enabled or disabled



WifiScan

controls whether wifi scans can be performed