SettingCompareFlags

Enum SettingCompareFlags 

#[non_exhaustive]
pub enum SettingCompareFlags { Exact, Fuzzy, IgnoreId, IgnoreSecrets, IgnoreAgentOwnedSecrets, IgnoreNotSavedSecrets, DiffResultWithDefault, DiffResultNoDefault, IgnoreTimestamp, }
These flags modify the comparison behavior when comparing two settings or two connections.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Exact

match all properties exactly



Fuzzy

match only important attributes, like SSID, type, security settings, etc. Does not match, for example, connection ID or UUID.



IgnoreId

ignore the connection’s ID



IgnoreSecrets

ignore all secrets



IgnoreAgentOwnedSecrets

ignore secrets for which the secret’s flags indicate the secret is owned by a user secret agent (ie, the secret’s flag includes @NM_SETTING_SECRET_FLAG_AGENT_OWNED)



IgnoreNotSavedSecrets

ignore secrets for which the secret’s flags indicate the secret should not be saved to persistent storage (ie, the secret’s flag includes @NM_SETTING_SECRET_FLAG_NOT_SAVED)



DiffResultWithDefault

if this flag is set, nm_setting_diff() and nm_connection_diff() will also include properties that are set to their default value. See also @NM_SETTING_COMPARE_FLAG_DIFF_RESULT_NO_DEFAULT.



DiffResultNoDefault

if this flag is set, nm_setting_diff() and nm_connection_diff() will not include properties that are set to their default value. This is the opposite of @NM_SETTING_COMPARE_FLAG_DIFF_RESULT_WITH_DEFAULT. If both flags are set together, @NM_SETTING_COMPARE_FLAG_DIFF_RESULT_WITH_DEFAULT wins. If both flags are unset, this means to exclude default properties if there is a setting to compare, but include all properties, if the setting ‘b’ is missing. This is the legacy behaviour of libnm-util, where nm_setting_diff() behaved differently depending on whether the setting ‘b’ was available. If @NM_SETTING_COMPARE_FLAG_DIFF_RESULT_WITH_DEFAULT is set, nm_setting_diff() will also set the flags @NM_SETTING_DIFF_RESULT_IN_A_DEFAULT and @NM_SETTING_DIFF_RESULT_IN_B_DEFAULT, if the values are default values.



IgnoreTimestamp

ignore the connection’s timestamp