pub struct VpnEditorPlugin { /* private fields */ }Expand description
Implementations
Sourceimpl VpnEditorPlugin
impl VpnEditorPlugin
pub const NONE: Option<&'static VpnEditorPlugin> = None
Sourcepub fn load(
plugin_name: &str,
check_service: &str,
) -> Result<VpnEditorPlugin, Error>
Available on crate feature v1_4 only.
pub fn load( plugin_name: &str, check_service: &str, ) -> Result<VpnEditorPlugin, Error>
v1_4 only.Load the shared library @plugin_name and create a new #NMVpnEditorPlugin instance via the #NMVpnEditorPluginFactory function.
This is similar to nm_vpn_editor_plugin_load_from_file(), but it does no validation of the plugin name, instead passes it directly to dlopen(). If you have the full path to a plugin file, nm_vpn_editor_plugin_load_from_file() is preferred.
plugin_name
The name of the shared library to load. This path will be directly passed to dlopen() without further checks.
check_service
if not-null, check that the loaded plugin advertises the given service.
Returns
a new plugin instance or None on error.